<?php
// $Id: theme-settings.php,v 1.9 2008/11/23 22:16:19 shannonlucas Exp $
/**
 * @file Provides the settings for the Notibe theme.
 */

require_once drupal_get_path('theme', 'nitobe') . '/nitobe_utils.php';

/**
 * Implementation of THEMEHOOK_settings().
 *
 * @param array $settings An array of saved settings for this
 *        theme.
 *
 * @return array A form array.
 */
function phptemplate_settings($settings) {
  $form = array();
  
  //--------------------------------------------------------------------------
  // Get the header image list.
  $images  = _nitobe_get_header_list(TRUE);
  $options = array('<random>' => 'Random Header Image');

  foreach ($images as $filename => $data) {
    $options[$filename] = $data->pretty_name;
  }

  //--------------------------------------------------------------------------
  // The setting for the header image.
  $current = empty($settings['nitobe_header_image']) ? '' : $settings['nitobe_header_image'];
  $default = in_array($current, array_keys($options)) ? $current : '<random>';
  $form['nitobe_header_image'] = array(
    '#type'          => 'select',
    '#title'         => t('Header image'),
    '#options'       => $options,
    '#default_value' => $default,
  );

  //--------------------------------------------------------------------------
  // Show the header image if the mastead region has content?
  $default = (!isset($settings['nitobe_header_always_show'])) ? FALSE : (boolean)$settings['nitobe_header_always_show'];
  $form['nitobe_header_always_show'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Force Header Image'),
    '#default_value' => $default,
    '#description'   => t("By default, if there is block content in the masthead region, the header image will not be displayed. Check this box to cause the header image to be displayed as the region's background image."),
  );

  //--------------------------------------------------------------------------
  // Show the breadcrumb trail if it only contains the 'Home' link?
  $default = empty($settings['nitobe_show_single_crumb']) ? FALSE : (boolean)$settings['nitobe_show_single_crumb'];
  $form['nitobe_show_single_crumb'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Show single item breadcrumb trail'),
    '#default_value' => $default,
    '#description'   => t('By default the breadcrumb trail will be hidden if it contains just the link to the top level page. Check this box to override that behavior.'),
  );  

  //--------------------------------------------------------------------------
  // Strip the ' (not verified)' from output usernames?
  $default = empty($settings['nitobe_remove_not_verified']) ? FALSE : (boolean)$settings['nitobe_remove_not_verified'];
  $form['nitobe_remove_not_verified'] = array(
    '#type'          => 'checkbox',
    '#title'         => t("Strip '(not verified)' from usernames"),
    '#default_value' => $default,
    '#description'   => t("Normally, when an anonymous visitors posts a comment, their name is suffixed with '%verified'. Checking this will prevent that text from being added.",
                          array('%verified' => ' (not verified)')),
  );

  //--------------------------------------------------------------------------
  // Strip the ' (not verified)' from output usernames?
  $default = empty($settings['nitobe_suppress_comment_reply']) ? FALSE : (boolean)$settings['nitobe_suppress_comment_reply'];
  $form['nitobe_suppress_comment_reply'] = array(
    '#type'          => 'checkbox',
    '#title'         => t("Suppress 'Reply' link in comments"),
    '#default_value' => $default,
    '#description'   => t('Suppresses the reply link to prevent vistors from replying to individual comments.'),
  );

  //--------------------------------------------------------------------------
  // Which content types to show a datestamp in the headline for?
  $default = $settings['nitobe_show_datestamp'];
  $default = (!empty($default)) ? $default : array('blog', 'forum', 'poll', 'story');
  $types   = node_get_types('names');
  $options = array();

  foreach($types as $name => $type_obj) {
    $options[$name] = $type_obj;
  }

  $form['nitobe_show_datestamp'] = array(
    '#type'          => 'select',
    '#multiple'      => TRUE,
    '#title'         => t('Show date stamp'),
    '#default_value' => $default,
    '#options'       => $options,
    '#description'   => t('Content types selected here will display a date stamp in their headline.'),
  );

  return $form;
}
